pub fn needs_migration(log: &ObservationLog) -> boolExpand description
True when the log holds anything written before raw-φ logging.
pub fn needs_migration(log: &ObservationLog) -> boolTrue when the log holds anything written before raw-φ logging.