pub fn rect_mode_index(x: f64) -> usizeExpand description
Which of RECT_MODES a normalized rmode knob selects — cell centres on
a three-way split, the convention the other quantized knobs use.
pub fn rect_mode_index(x: f64) -> usizeWhich of RECT_MODES a normalized rmode knob selects — cell centres on
a three-way split, the convention the other quantized knobs use.