pub fn compile(
tree: &PatchTree,
sample_rate: f64,
) -> Result<CompiledVoice, PatchError>Expand description
Compile a patch term into a playable voice at the given sample rate.
pub fn compile(
tree: &PatchTree,
sample_rate: f64,
) -> Result<CompiledVoice, PatchError>Compile a patch term into a playable voice at the given sample rate.